@@ -69,10 +69,12 @@ NS_OBJECT_ENSURE_REGISTERED (LteSpectrumPhy);
 
 LteSpectrumPhy::LteSpectrumPhy ()
   : m_state (IDLE),
-  m_random (0.0, 1.0),
   m_transmissionMode (0)
 {
   NS_LOG_FUNCTION (this);
+  m_random = CreateObject<UniformRandomVariable> ();
+  m_random->SetAttribute ("Min", DoubleValue (0.0));
+  m_random->SetAttribute ("Max", DoubleValue (1.0));
   m_interference = CreateObject<LteInterference> ();
   for (uint8_t i = 0; i < 7; i++)
     {
@@ -494,7 +496,7 @@ LteSpectrumPhy::EndRx ()
       if (m_pemEnabled)
         {
           double errorRate = LteMiErrorModel::GetTbError (m_sinrPerceived, (*itTb).second.rbBitmap, (*itTb).second.size, (*itTb).second.mcs);
-          (*itTb).second.corrupt = m_random.GetValue () > errorRate ? false : true;
+          (*itTb).second.corrupt = m_random->GetValue () > errorRate ? false : true;
           NS_LOG_DEBUG (this << "RNTI " << (*itTb).first.m_rnti << " size " << (*itTb).second.size << " mcs " << (uint32_t)(*itTb).second.mcs << " bitmap " << (*itTb).second.rbBitmap.size () << " layer " << (uint16_t)(*itTb).first.m_layer << " ErrorRate " << errorRate << " corrupted " << (*itTb).second.corrupt);
        }
       
@@ -589,6 +591,14 @@ LteSpectrumPhy::SetTxModeGain (uint8_t txMode, double gain)
   }
 }
 
+int64_t
+LteSpectrumPhy::AssignStreams (int64_t stream)
+{
+  NS_LOG_FUNCTION (this << stream);
+  m_random->SetStream (stream);
+  return 1;
+}
+
 
 
 } // namespace ns3
