@@ -13,6 +13,8 @@ cpp_examples = [
     ("lena-dual-stripe --simTime=0.01", "True", "True"),
     ("lena-dual-stripe --epc=1 --simTime=0.01", "True", "True"),
     ("lena-dual-stripe --epc=1 --useUdp=0 --simTime=0.01", "True", "True"),
+    ("lena-dual-stripe --epc=1 --fadingTrace=../../src/lte/model/fading-traces/fading_trace_EPA_3kmph.fad --simTime=0.01", "True", "True"),
+    ("lena-dual-stripe --nBlocks=1  --nMacroEnbSites=0 --macroUeDensity=0 --homeEnbDeploymentRatio=1 --homeEnbActivationRatio=1 --homeUesHomeEnbRatio=2 --macroEnbTxPowerDbm=0 --simTime=0.01", "True", "True"),
     ("lena-fading", "True", "True"),
     ("lena-gtpu-tunnel", "True", "True"),
     ("lena-intercell-interference", "True", "True"),
