@@ -32,7 +32,6 @@
 #include "ns3/uan-tx-mode.h"
 #include "ns3/node.h"
 #include "ns3/uinteger.h"
-#include "ns3/random-variable.h"
 #include "ns3/energy-source-container.h"
 #include "ns3/acoustic-modem-energy-model.h"
 
@@ -357,6 +356,8 @@ UanPhyGen::UanPhyGen ()
     m_cleared (false),
     m_disabled (false)
 {
+  m_pg = CreateObject<UniformRandomVariable> ();
+
   m_energyCallback.Nullify ();
 }
 
@@ -428,7 +429,7 @@ UanPhyGen::GetTypeId (void)
 {
 
   static TypeId tid = TypeId ("ns3::UanPhyGen")
-    .SetParent<Object> ()
+    .SetParent<UanPhy> ()
     .AddConstructor<UanPhyGen> ()
     .AddAttribute ("CcaThreshold",
                    "Aggregate energy of incoming signals to move to CCA Busy state dB",
@@ -581,12 +582,14 @@ UanPhyGen::StartRxPacket (Ptr<Packet> pkt, double rxPowerDb, UanTxMode txMode, U
   if (m_disabled)
     {
       NS_LOG_DEBUG ("Energy depleted, node cannot receive any packet. Dropping.");
+      NotifyRxDrop(pkt);    // traced source netanim
       return;
     }
 
   switch (m_state)
     {
     case TX:
+      NotifyRxDrop(pkt);    // traced source netanim
       NS_ASSERT (false);
       break;
     case RX:
@@ -595,6 +598,7 @@ UanPhyGen::StartRxPacket (Ptr<Packet> pkt, double rxPowerDb, UanTxMode txMode, U
         double newSinrDb = CalculateSinrDb (m_pktRx, m_pktRxArrTime, m_rxRecvPwrDb, m_pktRxMode, m_pktRxPdp);
         m_minRxSinrDb  =  (newSinrDb < m_minRxSinrDb) ? newSinrDb : m_minRxSinrDb;
         NS_LOG_DEBUG ("PHY " << m_mac->GetAddress () << ": Starting RX in RX mode.  SINR of pktRx = " << m_minRxSinrDb);
+        NotifyRxBegin(pkt);    // traced source netanim
       }
       break;
 
@@ -623,6 +627,7 @@ UanPhyGen::StartRxPacket (Ptr<Packet> pkt, double rxPowerDb, UanTxMode txMode, U
           {
             m_state = RX;
             UpdatePowerConsumption (RX);
+            NotifyRxBegin(pkt);    // traced source netanim
             m_rxRecvPwrDb = rxPowerDb;
             m_minRxSinrDb = newsinr;
             m_pktRx = pkt;
@@ -638,6 +643,7 @@ UanPhyGen::StartRxPacket (Ptr<Packet> pkt, double rxPowerDb, UanTxMode txMode, U
       break;
     case SLEEP:
       NS_LOG_DEBUG ("Sleep mode. Dropping packet.");
+      NotifyRxDrop(pkt);    // traced source netanim
       break;
     }
 
@@ -661,9 +667,11 @@ UanPhyGen::RxEndEvent (Ptr<Packet> pkt, double rxPowerDb, UanTxMode txMode)
     {
       NS_LOG_DEBUG ("Sleep mode or dead. Dropping packet");
       m_pktRx = 0;
+      NotifyRxDrop(pkt);    // traced source netanim
       return;
     }
 
+  NotifyRxEnd(pkt);    // traced source netanim
   if (GetInterferenceDb ( (Ptr<Packet>) 0) > m_ccaThreshDb)
     {
       m_state = CCABUSY;
@@ -675,9 +683,7 @@ UanPhyGen::RxEndEvent (Ptr<Packet> pkt, double rxPowerDb, UanTxMode txMode)
       UpdatePowerConsumption (IDLE);
     }
 
-  UniformVariable pg;
-
-  if (pg.GetValue (0, 1) > m_per->CalcPer (m_pktRx, m_minRxSinrDb, txMode))
+  if (m_pg->GetValue (0, 1) > m_per->CalcPer (m_pktRx, m_minRxSinrDb, txMode))
     {
       m_rxOkLogger (pkt, m_minRxSinrDb, txMode);
       NotifyListenersRxGood ();
@@ -859,6 +865,14 @@ UanPhyGen::SetSleepMode (bool sleep)
     }
 }
 
+int64_t
+UanPhyGen::AssignStreams (int64_t stream)
+{
+  NS_LOG_FUNCTION (this << stream);
+  m_pg->SetStream (stream);
+  return 1;
+}
+
 void
 UanPhyGen::NotifyTransStartTx (Ptr<Packet> packet, double txPowerDb, UanTxMode txMode)
 {
