@@ -1113,7 +1113,8 @@ def run_tests():
     if options.list:
         path_cmd = os.path.join("utils", test_runner_name + " --print-test-name-list")
         (rc, standard_out, standard_err, et) = run_job_synchronously(path_cmd, os.getcwd(), False, False)
-        print standard_out
+        list_items = standard_out.split('\n')
+        print "\n".join(sorted(list_items))
 
     if options.kinds or options.list:
         return
